from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VaultType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAULT_TYPE_UNSPECIFIED: _ClassVar[VaultType]
    VAULT_TYPE_CLOB: _ClassVar[VaultType]

class VaultStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAULT_STATUS_UNSPECIFIED: _ClassVar[VaultStatus]
    VAULT_STATUS_DEACTIVATED: _ClassVar[VaultStatus]
    VAULT_STATUS_STAND_BY: _ClassVar[VaultStatus]
    VAULT_STATUS_QUOTING: _ClassVar[VaultStatus]
    VAULT_STATUS_CLOSE_ONLY: _ClassVar[VaultStatus]
VAULT_TYPE_UNSPECIFIED: VaultType
VAULT_TYPE_CLOB: VaultType
VAULT_STATUS_UNSPECIFIED: VaultStatus
VAULT_STATUS_DEACTIVATED: VaultStatus
VAULT_STATUS_STAND_BY: VaultStatus
VAULT_STATUS_QUOTING: VaultStatus
VAULT_STATUS_CLOSE_ONLY: VaultStatus

class VaultId(_message.Message):
    __slots__ = ("type", "number")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    type: VaultType
    number: int
    def __init__(self, type: _Optional[_Union[VaultType, str]] = ..., number: _Optional[int] = ...) -> None: ...
