# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/protocol/v1/perpetual.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/protocol/v1/perpetual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/indexer/protocol/v1/perpetual.proto\x12 dydxprotocol.indexer.protocol.v1*\x81\x01\n\x13PerpetualMarketType\x12%\n!PERPETUAL_MARKET_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPERPETUAL_MARKET_TYPE_CROSS\x10\x01\x12\"\n\x1ePERPETUAL_MARKET_TYPE_ISOLATED\x10\x02\x42\x45ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.protocol.v1.perpetual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/types'
  _globals['_PERPETUALMARKETTYPE']._serialized_start=87
  _globals['_PERPETUALMARKETTYPE']._serialized_end=216
# @@protoc_insertion_point(module_scope)
