# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/perpetuals/perpetual.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/perpetuals/perpetual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'dydxprotocol/perpetuals/perpetual.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\"\x8d\x02\n\tPerpetual\x12>\n\x06params\x18\x01 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00\x12_\n\rfunding_index\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12_\n\ropen_interest\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xd3\x01\n\x0fPerpetualParams\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x04 \x01(\x11\x12\x1b\n\x13\x64\x65\x66\x61ult_funding_ppm\x18\x05 \x01(\x11\x12\x16\n\x0eliquidity_tier\x18\x06 \x01(\r\x12\x41\n\x0bmarket_type\x18\x07 \x01(\x0e\x32,.dydxprotocol.perpetuals.PerpetualMarketType\"8\n\x0eMarketPremiums\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x10\n\x08premiums\x18\x02 \x03(\x11\"p\n\x0cPremiumStore\x12J\n\x13\x61ll_market_premiums\x18\x01 \x03(\x0b\x32\'.dydxprotocol.perpetuals.MarketPremiumsB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cnum_premiums\x18\x02 \x01(\r\"\xe6\x01\n\rLiquidityTier\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01\x12\x17\n\x0fimpact_notional\x18\x06 \x01(\x04\x12\x1f\n\x17open_interest_lower_cap\x18\x07 \x01(\x04\x12\x1f\n\x17open_interest_upper_cap\x18\x08 \x01(\x04*\x81\x01\n\x13PerpetualMarketType\x12%\n!PERPETUAL_MARKET_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPERPETUAL_MARKET_TYPE_CROSS\x10\x01\x12\"\n\x1ePERPETUAL_MARKET_TYPE_ISOLATED\x10\x02\x42>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.perpetual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_PERPETUAL'].fields_by_name['params']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_PERPETUAL'].fields_by_name['funding_index']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['funding_index']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PERPETUAL'].fields_by_name['open_interest']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['open_interest']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PREMIUMSTORE'].fields_by_name['all_market_premiums']._loaded_options = None
  _globals['_PREMIUMSTORE'].fields_by_name['all_market_premiums']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDITYTIER'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIER'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_PERPETUALMARKETTYPE']._serialized_start=982
  _globals['_PERPETUALMARKETTYPE']._serialized_end=1111
  _globals['_PERPETUAL']._serialized_start=91
  _globals['_PERPETUAL']._serialized_end=360
  _globals['_PERPETUALPARAMS']._serialized_start=363
  _globals['_PERPETUALPARAMS']._serialized_end=574
  _globals['_MARKETPREMIUMS']._serialized_start=576
  _globals['_MARKETPREMIUMS']._serialized_end=632
  _globals['_PREMIUMSTORE']._serialized_start=634
  _globals['_PREMIUMSTORE']._serialized_end=746
  _globals['_LIQUIDITYTIER']._serialized_start=749
  _globals['_LIQUIDITYTIER']._serialized_end=979
# @@protoc_insertion_point(module_scope)
