# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/prices/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/prices/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as dydxprotocol_dot_prices_dot_market__param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64ydxprotocol/prices/tx.proto\x12\x13\x64ydxprotocol.prices\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a&dydxprotocol/prices/market_param.proto\"\x8c\x01\n\x15MsgCreateOracleMarket\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1f\n\x1dMsgCreateOracleMarketResponse\"\x9e\x01\n\x15MsgUpdateMarketPrices\x12T\n\x14market_price_updates\x18\x01 \x03(\x0b\x32\x36.dydxprotocol.prices.MsgUpdateMarketPrices.MarketPrice\x1a/\n\x0bMarketPrice\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\x04\"\x1f\n\x1dMsgUpdateMarketPricesResponse\"\x91\x01\n\x14MsgUpdateMarketParam\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x0cmarket_param\x18\x02 \x01(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgUpdateMarketParamResponse2\xe4\x02\n\x03Msg\x12t\n\x12UpdateMarketPrices\x12*.dydxprotocol.prices.MsgUpdateMarketPrices\x1a\x32.dydxprotocol.prices.MsgUpdateMarketPricesResponse\x12t\n\x12\x43reateOracleMarket\x12*.dydxprotocol.prices.MsgCreateOracleMarket\x1a\x32.dydxprotocol.prices.MsgCreateOracleMarketResponse\x12q\n\x11UpdateMarketParam\x12).dydxprotocol.prices.MsgUpdateMarketParam\x1a\x31.dydxprotocol.prices.MsgUpdateMarketParamResponseB:Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.prices.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/types'
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['params']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEORACLEMARKET']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['market_param']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['market_param']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEMARKETPARAM']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEORACLEMARKET']._serialized_start=168
  _globals['_MSGCREATEORACLEMARKET']._serialized_end=308
  _globals['_MSGCREATEORACLEMARKETRESPONSE']._serialized_start=310
  _globals['_MSGCREATEORACLEMARKETRESPONSE']._serialized_end=341
  _globals['_MSGUPDATEMARKETPRICES']._serialized_start=344
  _globals['_MSGUPDATEMARKETPRICES']._serialized_end=502
  _globals['_MSGUPDATEMARKETPRICES_MARKETPRICE']._serialized_start=455
  _globals['_MSGUPDATEMARKETPRICES_MARKETPRICE']._serialized_end=502
  _globals['_MSGUPDATEMARKETPRICESRESPONSE']._serialized_start=504
  _globals['_MSGUPDATEMARKETPRICESRESPONSE']._serialized_end=535
  _globals['_MSGUPDATEMARKETPARAM']._serialized_start=538
  _globals['_MSGUPDATEMARKETPARAM']._serialized_end=683
  _globals['_MSGUPDATEMARKETPARAMRESPONSE']._serialized_start=685
  _globals['_MSGUPDATEMARKETPARAMRESPONSE']._serialized_end=715
  _globals['_MSG']._serialized_start=718
  _globals['_MSG']._serialized_end=1074
# @@protoc_insertion_point(module_scope)
