# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/epochs/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/epochs/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.epochs import epoch_info_pb2 as dydxprotocol_dot_epochs_dot_epoch__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/epochs/query.proto\x12\x13\x64ydxprotocol.epochs\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a$dydxprotocol/epochs/epoch_info.proto\"(\n\x18QueryGetEpochInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"R\n\x16QueryEpochInfoResponse\x12\x38\n\nepoch_info\x18\x01 \x01(\x0b\x32\x1e.dydxprotocol.epochs.EpochInfoB\x04\xc8\xde\x1f\x00\"V\n\x18QueryAllEpochInfoRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x92\x01\n\x19QueryEpochInfoAllResponse\x12\x38\n\nepoch_info\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.epochs.EpochInfoB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xc0\x02\n\x05Query\x12\x9a\x01\n\tEpochInfo\x12-.dydxprotocol.epochs.QueryGetEpochInfoRequest\x1a+.dydxprotocol.epochs.QueryEpochInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/v4/epochs/epoch_info/{name}\x12\x99\x01\n\x0c\x45pochInfoAll\x12-.dydxprotocol.epochs.QueryAllEpochInfoRequest\x1a..dydxprotocol.epochs.QueryEpochInfoAllResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/v4/epochs/epoch_infoB:Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.epochs.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/types'
  _globals['_QUERYEPOCHINFORESPONSE'].fields_by_name['epoch_info']._loaded_options = None
  _globals['_QUERYEPOCHINFORESPONSE'].fields_by_name['epoch_info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEPOCHINFOALLRESPONSE'].fields_by_name['epoch_info']._loaded_options = None
  _globals['_QUERYEPOCHINFOALLRESPONSE'].fields_by_name['epoch_info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['EpochInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EpochInfo']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/v4/epochs/epoch_info/{name}'
  _globals['_QUERY'].methods_by_name['EpochInfoAll']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EpochInfoAll']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/v4/epochs/epoch_info'
  _globals['_QUERYGETEPOCHINFOREQUEST']._serialized_start=190
  _globals['_QUERYGETEPOCHINFOREQUEST']._serialized_end=230
  _globals['_QUERYEPOCHINFORESPONSE']._serialized_start=232
  _globals['_QUERYEPOCHINFORESPONSE']._serialized_end=314
  _globals['_QUERYALLEPOCHINFOREQUEST']._serialized_start=316
  _globals['_QUERYALLEPOCHINFOREQUEST']._serialized_end=402
  _globals['_QUERYEPOCHINFOALLRESPONSE']._serialized_start=405
  _globals['_QUERYEPOCHINFOALLRESPONSE']._serialized_end=551
  _globals['_QUERY']._serialized_start=554
  _globals['_QUERY']._serialized_end=874
# @@protoc_insertion_point(module_scope)
