# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/query.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x14\n\x12QueryParamsRequest\"\xa1\x01\n\x13QueryParamsResponse\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x01 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00\x12\x41\n\x0foperator_params\x18\x02 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00\"P\n\x11QueryVaultRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xa2\x03\n\x12QueryVaultResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12\x43\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12X\n\x06\x65quity\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12[\n\tinventory\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12;\n\x0cvault_params\x18\x05 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x06 \x03(\r\"S\n\x15QueryAllVaultsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x16QueryAllVaultsResponse\x12\x36\n\x06vaults\x18\x01 \x03(\x0b\x32&.dydxprotocol.vault.QueryVaultResponse\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\"\n QueryMegavaultTotalSharesRequest\"X\n!QueryMegavaultTotalSharesResponse\x12\x33\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\"M\n QueryMegavaultOwnerSharesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x82\x03\n!QueryMegavaultOwnerSharesResponse\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12<\n\rshare_unlocks\x18\x03 \x03(\x0b\x32\x1f.dydxprotocol.vault.ShareUnlockB\x04\xc8\xde\x1f\x00\x12X\n\x06\x65quity\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x65\n\x13withdrawable_equity\x18\x05 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"a\n#QueryMegavaultAllOwnerSharesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x99\x01\n$QueryMegavaultAllOwnerSharesResponse\x12\x34\n\x0cowner_shares\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"V\n\x17QueryVaultParamsRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\x8c\x01\n\x18QueryVaultParamsResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\"f\n#QueryMegavaultWithdrawalInfoRequest\x12?\n\x12shares_to_withdraw\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\xf1\x02\n$QueryMegavaultWithdrawalInfoResponse\x12?\n\x12shares_to_withdraw\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12i\n\x17\x65xpected_quote_quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x62\n\x10megavault_equity\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x39\n\x0ctotal_shares\x18\x04 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x32\xc7\n\n\x05Query\x12}\n\x06Params\x12&.dydxprotocol.vault.QueryParamsRequest\x1a\'.dydxprotocol.vault.QueryParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/dydxprotocol/vault/params\x12\x89\x01\n\x05Vault\x12%.dydxprotocol.vault.QueryVaultRequest\x1a&.dydxprotocol.vault.QueryVaultResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/vault/vault/{type}/{number}\x12\x85\x01\n\tAllVaults\x12).dydxprotocol.vault.QueryAllVaultsRequest\x1a*.dydxprotocol.vault.QueryAllVaultsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/dydxprotocol/vault/vault\x12\xb7\x01\n\x14MegavaultTotalShares\x12\x34.dydxprotocol.vault.QueryMegavaultTotalSharesRequest\x1a\x35.dydxprotocol.vault.QueryMegavaultTotalSharesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/vault/megavault/total_shares\x12\xc1\x01\n\x14MegavaultOwnerShares\x12\x34.dydxprotocol.vault.QueryMegavaultOwnerSharesRequest\x1a\x35.dydxprotocol.vault.QueryMegavaultOwnerSharesResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/dydxprotocol/vault/megavault/owner_shares/{address}\x12\xc4\x01\n\x17MegavaultAllOwnerShares\x12\x37.dydxprotocol.vault.QueryMegavaultAllOwnerSharesRequest\x1a\x38.dydxprotocol.vault.QueryMegavaultAllOwnerSharesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/vault/megavault/all_owner_shares\x12\x9c\x01\n\x0bVaultParams\x12+.dydxprotocol.vault.QueryVaultParamsRequest\x1a,.dydxprotocol.vault.QueryVaultParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/vault/params/{type}/{number}\x12\xc6\x01\n\x17MegavaultWithdrawalInfo\x12\x37.dydxprotocol.vault.QueryMegavaultWithdrawalInfoRequest\x1a\x38.dydxprotocol.vault.QueryMegavaultWithdrawalInfoResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/dydxprotocol/vault/megavault/withdrawal_info:\x01*B9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['operator_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['operator_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['equity']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['inventory']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['inventory']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_params']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['shares']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['share_unlocks']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['withdrawable_equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE'].fields_by_name['withdrawable_equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_params']._loaded_options = None
  _globals['_QUERYVAULTPARAMSRESPONSE'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST'].fields_by_name['shares_to_withdraw']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST'].fields_by_name['shares_to_withdraw']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['shares_to_withdraw']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['shares_to_withdraw']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['expected_quote_quantums']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['expected_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['megavault_equity']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['megavault_equity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['total_shares']._loaded_options = None
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE'].fields_by_name['total_shares']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\034\022\032/dydxprotocol/vault/params'
  _globals['_QUERY'].methods_by_name['Vault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vault']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/vault/vault/{type}/{number}'
  _globals['_QUERY'].methods_by_name['AllVaults']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllVaults']._serialized_options = b'\202\323\344\223\002\033\022\031/dydxprotocol/vault/vault'
  _globals['_QUERY'].methods_by_name['MegavaultTotalShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultTotalShares']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/vault/megavault/total_shares'
  _globals['_QUERY'].methods_by_name['MegavaultOwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultOwnerShares']._serialized_options = b'\202\323\344\223\0026\0224/dydxprotocol/vault/megavault/owner_shares/{address}'
  _globals['_QUERY'].methods_by_name['MegavaultAllOwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultAllOwnerShares']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/vault/megavault/all_owner_shares'
  _globals['_QUERY'].methods_by_name['VaultParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VaultParams']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/vault/params/{type}/{number}'
  _globals['_QUERY'].methods_by_name['MegavaultWithdrawalInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MegavaultWithdrawalInfo']._serialized_options = b'\202\323\344\223\0022\"-/dydxprotocol/vault/megavault/withdrawal_info:\001*'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=317
  _globals['_QUERYPARAMSREQUEST']._serialized_end=337
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=340
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=501
  _globals['_QUERYVAULTREQUEST']._serialized_start=503
  _globals['_QUERYVAULTREQUEST']._serialized_end=583
  _globals['_QUERYVAULTRESPONSE']._serialized_start=586
  _globals['_QUERYVAULTRESPONSE']._serialized_end=1004
  _globals['_QUERYALLVAULTSREQUEST']._serialized_start=1006
  _globals['_QUERYALLVAULTSREQUEST']._serialized_end=1089
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_start=1092
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_end=1233
  _globals['_QUERYMEGAVAULTTOTALSHARESREQUEST']._serialized_start=1235
  _globals['_QUERYMEGAVAULTTOTALSHARESREQUEST']._serialized_end=1269
  _globals['_QUERYMEGAVAULTTOTALSHARESRESPONSE']._serialized_start=1271
  _globals['_QUERYMEGAVAULTTOTALSHARESRESPONSE']._serialized_end=1359
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST']._serialized_start=1361
  _globals['_QUERYMEGAVAULTOWNERSHARESREQUEST']._serialized_end=1438
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE']._serialized_start=1441
  _globals['_QUERYMEGAVAULTOWNERSHARESRESPONSE']._serialized_end=1827
  _globals['_QUERYMEGAVAULTALLOWNERSHARESREQUEST']._serialized_start=1829
  _globals['_QUERYMEGAVAULTALLOWNERSHARESREQUEST']._serialized_end=1926
  _globals['_QUERYMEGAVAULTALLOWNERSHARESRESPONSE']._serialized_start=1929
  _globals['_QUERYMEGAVAULTALLOWNERSHARESRESPONSE']._serialized_end=2082
  _globals['_QUERYVAULTPARAMSREQUEST']._serialized_start=2084
  _globals['_QUERYVAULTPARAMSREQUEST']._serialized_end=2170
  _globals['_QUERYVAULTPARAMSRESPONSE']._serialized_start=2173
  _globals['_QUERYVAULTPARAMSRESPONSE']._serialized_end=2313
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST']._serialized_start=2315
  _globals['_QUERYMEGAVAULTWITHDRAWALINFOREQUEST']._serialized_end=2417
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE']._serialized_start=2420
  _globals['_QUERYMEGAVAULTWITHDRAWALINFORESPONSE']._serialized_end=2789
  _globals['_QUERY']._serialized_start=2792
  _globals['_QUERY']._serialized_end=4143
# @@protoc_insertion_point(module_scope)
