# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/affiliates/affiliates.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/affiliates/affiliates.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/affiliates/affiliates.proto\x12\x17\x64ydxprotocol.affiliates\x1a\x14gogoproto/gogo.proto\"\xc4\x01\n\x0e\x41\x66\x66iliateTiers\x12\x41\n\x05tiers\x18\x01 \x03(\x0b\x32,.dydxprotocol.affiliates.AffiliateTiers.TierB\x04\xc8\xde\x1f\x00\x1ao\n\x04Tier\x12*\n\"req_referred_volume_quote_quantums\x18\x01 \x01(\x04\x12\x1e\n\x16req_staked_whole_coins\x18\x02 \x01(\r\x12\x1b\n\x13taker_fee_share_ppm\x18\x03 \x01(\r\"\x93\x01\n\x12\x41\x66\x66iliateWhitelist\x12\x45\n\x05tiers\x18\x01 \x03(\x0b\x32\x30.dydxprotocol.affiliates.AffiliateWhitelist.TierB\x04\xc8\xde\x1f\x00\x1a\x36\n\x04Tier\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1b\n\x13taker_fee_share_ppm\x18\x02 \x01(\rB>Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.affiliates.affiliates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/types'
  _globals['_AFFILIATETIERS'].fields_by_name['tiers']._loaded_options = None
  _globals['_AFFILIATETIERS'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATEWHITELIST'].fields_by_name['tiers']._loaded_options = None
  _globals['_AFFILIATEWHITELIST'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATETIERS']._serialized_start=92
  _globals['_AFFILIATETIERS']._serialized_end=288
  _globals['_AFFILIATETIERS_TIER']._serialized_start=177
  _globals['_AFFILIATETIERS_TIER']._serialized_end=288
  _globals['_AFFILIATEWHITELIST']._serialized_start=291
  _globals['_AFFILIATEWHITELIST']._serialized_end=438
  _globals['_AFFILIATEWHITELIST_TIER']._serialized_start=384
  _globals['_AFFILIATEWHITELIST_TIER']._serialized_end=438
# @@protoc_insertion_point(module_scope)
