# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/shared/removal_reason.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/shared/removal_reason.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/indexer/shared/removal_reason.proto\x12\x1b\x64ydxprotocol.indexer.shared*\xf6\x05\n\x12OrderRemovalReason\x12$\n ORDER_REMOVAL_REASON_UNSPECIFIED\x10\x00\x12 \n\x1cORDER_REMOVAL_REASON_EXPIRED\x10\x01\x12&\n\"ORDER_REMOVAL_REASON_USER_CANCELED\x10\x02\x12,\n(ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED\x10\x03\x12\'\n#ORDER_REMOVAL_REASON_INTERNAL_ERROR\x10\x04\x12)\n%ORDER_REMOVAL_REASON_SELF_TRADE_ERROR\x10\x05\x12:\n6ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER\x10\x06\x12?\n;ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK\x10\x07\x12<\n8ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED\x10\x08\x12+\n\'ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE\x10\t\x12(\n$ORDER_REMOVAL_REASON_INDEXER_EXPIRED\x10\n\x12!\n\x1dORDER_REMOVAL_REASON_REPLACED\x10\x0b\x12%\n!ORDER_REMOVAL_REASON_FULLY_FILLED\x10\x0c\x12$\n ORDER_REMOVAL_REASON_EQUITY_TIER\x10\r\x12)\n%ORDER_REMOVAL_REASON_FINAL_SETTLEMENT\x10\x0e\x12\x41\n=ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS\x10\x0f\x42@Z>github.com/dydxprotocol/v4-chain/protocol/indexer/shared/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.shared.removal_reason_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dydxprotocol/v4-chain/protocol/indexer/shared/types'
  _globals['_ORDERREMOVALREASON']._serialized_start=82
  _globals['_ORDERREMOVALREASON']._serialized_end=840
# @@protoc_insertion_point(module_scope)
