# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/ratelimit/capacity.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/ratelimit/capacity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as dydxprotocol_dot_ratelimit_dot_limit__params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%dydxprotocol/ratelimit/capacity.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/ratelimit/limit_params.proto\"\x7f\n\rDenomCapacity\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12_\n\rcapacity_list\x18\x02 \x03(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xa5\x01\n\x0fLimiterCapacity\x12\x36\n\x07limiter\x18\x01 \x01(\x0b\x32\x1f.dydxprotocol.ratelimit.LimiterB\x04\xc8\xde\x1f\x00\x12Z\n\x08\x63\x61pacity\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.capacity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_DENOMCAPACITY'].fields_by_name['capacity_list']._loaded_options = None
  _globals['_DENOMCAPACITY'].fields_by_name['capacity_list']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIMITERCAPACITY'].fields_by_name['limiter']._loaded_options = None
  _globals['_LIMITERCAPACITY'].fields_by_name['limiter']._serialized_options = b'\310\336\037\000'
  _globals['_LIMITERCAPACITY'].fields_by_name['capacity']._loaded_options = None
  _globals['_LIMITERCAPACITY'].fields_by_name['capacity']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_DENOMCAPACITY']._serialized_start=130
  _globals['_DENOMCAPACITY']._serialized_end=257
  _globals['_LIMITERCAPACITY']._serialized_start=260
  _globals['_LIMITERCAPACITY']._serialized_end=425
# @@protoc_insertion_point(module_scope)
