# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/affiliates/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/affiliates/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as dydxprotocol_dot_affiliates_dot_affiliates__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/affiliates/query.proto\x12\x17\x64ydxprotocol.affiliates\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a(dydxprotocol/affiliates/affiliates.proto\x1a\x1cgoogle/api/annotations.proto\"A\n\x14\x41\x66\x66iliateInfoRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x98\x02\n\x15\x41\x66\x66iliateInfoResponse\x12\x16\n\x0eis_whitelisted\x18\x01 \x01(\x08\x12\x0c\n\x04tier\x18\x02 \x01(\r\x12\x15\n\rfee_share_ppm\x18\x03 \x01(\r\x12\x61\n\x0freferred_volume\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12_\n\rstaked_amount\x18\x05 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\">\n\x11ReferredByRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"I\n\x12ReferredByResponse\x12\x33\n\x11\x61\x66\x66iliate_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x1a\n\x18\x41llAffiliateTiersRequest\"Y\n\x19\x41llAffiliateTiersResponse\x12<\n\x05tiers\x18\x01 \x01(\x0b\x32\'.dydxprotocol.affiliates.AffiliateTiersB\x04\xc8\xde\x1f\x00\"\x1b\n\x19\x41\x66\x66iliateWhitelistRequest\"b\n\x1a\x41\x66\x66iliateWhitelistResponse\x12\x44\n\twhitelist\x18\x01 \x01(\x0b\x32+.dydxprotocol.affiliates.AffiliateWhitelistB\x04\xc8\xde\x1f\x00\x32\xbc\x05\n\x05Query\x12\xa9\x01\n\rAffiliateInfo\x12-.dydxprotocol.affiliates.AffiliateInfoRequest\x1a..dydxprotocol.affiliates.AffiliateInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/dydxprotocol/affiliates/affiliate_info/{address}\x12\x9d\x01\n\nReferredBy\x12*.dydxprotocol.affiliates.ReferredByRequest\x1a+.dydxprotocol.affiliates.ReferredByResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/affiliates/referred_by/{address}\x12\xb0\x01\n\x11\x41llAffiliateTiers\x12\x31.dydxprotocol.affiliates.AllAffiliateTiersRequest\x1a\x32.dydxprotocol.affiliates.AllAffiliateTiersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/affiliates/all_affiliate_tiers\x12\xb3\x01\n\x12\x41\x66\x66iliateWhitelist\x12\x32.dydxprotocol.affiliates.AffiliateWhitelistRequest\x1a\x33.dydxprotocol.affiliates.AffiliateWhitelistResponse\"4\x82\xd3\xe4\x93\x02.\x12,/dydxprotocol/affiliates/affiliate_whitelistB>Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.affiliates.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/affiliates/types'
  _globals['_AFFILIATEINFOREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_AFFILIATEINFOREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['referred_volume']._loaded_options = None
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['referred_volume']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['staked_amount']._loaded_options = None
  _globals['_AFFILIATEINFORESPONSE'].fields_by_name['staked_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_REFERREDBYREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_REFERREDBYREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_REFERREDBYRESPONSE'].fields_by_name['affiliate_address']._loaded_options = None
  _globals['_REFERREDBYRESPONSE'].fields_by_name['affiliate_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ALLAFFILIATETIERSRESPONSE'].fields_by_name['tiers']._loaded_options = None
  _globals['_ALLAFFILIATETIERSRESPONSE'].fields_by_name['tiers']._serialized_options = b'\310\336\037\000'
  _globals['_AFFILIATEWHITELISTRESPONSE'].fields_by_name['whitelist']._loaded_options = None
  _globals['_AFFILIATEWHITELISTRESPONSE'].fields_by_name['whitelist']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['AffiliateInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AffiliateInfo']._serialized_options = b'\202\323\344\223\0023\0221/dydxprotocol/affiliates/affiliate_info/{address}'
  _globals['_QUERY'].methods_by_name['ReferredBy']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ReferredBy']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/affiliates/referred_by/{address}'
  _globals['_QUERY'].methods_by_name['AllAffiliateTiers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllAffiliateTiers']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/affiliates/all_affiliate_tiers'
  _globals['_QUERY'].methods_by_name['AffiliateWhitelist']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AffiliateWhitelist']._serialized_options = b'\202\323\344\223\002.\022,/dydxprotocol/affiliates/affiliate_whitelist'
  _globals['_AFFILIATEINFOREQUEST']._serialized_start=185
  _globals['_AFFILIATEINFOREQUEST']._serialized_end=250
  _globals['_AFFILIATEINFORESPONSE']._serialized_start=253
  _globals['_AFFILIATEINFORESPONSE']._serialized_end=533
  _globals['_REFERREDBYREQUEST']._serialized_start=535
  _globals['_REFERREDBYREQUEST']._serialized_end=597
  _globals['_REFERREDBYRESPONSE']._serialized_start=599
  _globals['_REFERREDBYRESPONSE']._serialized_end=672
  _globals['_ALLAFFILIATETIERSREQUEST']._serialized_start=674
  _globals['_ALLAFFILIATETIERSREQUEST']._serialized_end=700
  _globals['_ALLAFFILIATETIERSRESPONSE']._serialized_start=702
  _globals['_ALLAFFILIATETIERSRESPONSE']._serialized_end=791
  _globals['_AFFILIATEWHITELISTREQUEST']._serialized_start=793
  _globals['_AFFILIATEWHITELISTREQUEST']._serialized_end=820
  _globals['_AFFILIATEWHITELISTRESPONSE']._serialized_start=822
  _globals['_AFFILIATEWHITELISTRESPONSE']._serialized_end=920
  _globals['_QUERY']._serialized_start=923
  _globals['_QUERY']._serialized_end=1623
# @@protoc_insertion_point(module_scope)
