# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/revshare/tx.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"\xaa\x01\n\x1eMsgSetMarketMapperRevenueShare\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12K\n\x06params\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"(\n&MsgSetMarketMapperRevenueShareResponse\"\xc6\x01\n*MsgSetMarketMapperRevShareDetailsForMarket\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\tmarket_id\x18\x02 \x01(\r\x12H\n\x06params\x18\x03 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"4\n2MsgSetMarketMapperRevShareDetailsForMarketResponse\"\xad\x01\n$MsgUpdateUnconditionalRevShareConfig\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x32.dydxprotocol.revshare.UnconditionalRevShareConfigB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\".\n,MsgUpdateUnconditionalRevShareConfigResponse\"\xaa\x01\n\x19MsgSetOrderRouterRevShare\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12P\n\x16order_router_rev_share\x18\x02 \x01(\x0b\x32*.dydxprotocol.revshare.OrderRouterRevShareB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"#\n!MsgSetOrderRouterRevShareResponse2\x84\x05\n\x03Msg\x12\x93\x01\n\x1bSetMarketMapperRevenueShare\x12\x35.dydxprotocol.revshare.MsgSetMarketMapperRevenueShare\x1a=.dydxprotocol.revshare.MsgSetMarketMapperRevenueShareResponse\x12\xb7\x01\n\'SetMarketMapperRevShareDetailsForMarket\x12\x41.dydxprotocol.revshare.MsgSetMarketMapperRevShareDetailsForMarket\x1aI.dydxprotocol.revshare.MsgSetMarketMapperRevShareDetailsForMarketResponse\x12\xa5\x01\n!UpdateUnconditionalRevShareConfig\x12;.dydxprotocol.revshare.MsgUpdateUnconditionalRevShareConfig\x1a\x43.dydxprotocol.revshare.MsgUpdateUnconditionalRevShareConfigResponse\x12\x84\x01\n\x16SetOrderRouterRevShare\x12\x30.dydxprotocol.revshare.MsgSetOrderRouterRevShare\x1a\x38.dydxprotocol.revshare.MsgSetOrderRouterRevShareResponseB<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['params']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['params']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._loaded_options = None
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['config']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG'].fields_by_name['config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._loaded_options = None
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['order_router_rev_share']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE'].fields_by_name['order_router_rev_share']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETORDERROUTERREVSHARE']._loaded_options = None
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_start=206
  _globals['_MSGSETMARKETMAPPERREVENUESHARE']._serialized_end=376
  _globals['_MSGSETMARKETMAPPERREVENUESHARERESPONSE']._serialized_start=378
  _globals['_MSGSETMARKETMAPPERREVENUESHARERESPONSE']._serialized_end=418
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_start=421
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKET']._serialized_end=619
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKETRESPONSE']._serialized_start=621
  _globals['_MSGSETMARKETMAPPERREVSHAREDETAILSFORMARKETRESPONSE']._serialized_end=673
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_start=676
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIG']._serialized_end=849
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_start=851
  _globals['_MSGUPDATEUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_end=897
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_start=900
  _globals['_MSGSETORDERROUTERREVSHARE']._serialized_end=1070
  _globals['_MSGSETORDERROUTERREVSHARERESPONSE']._serialized_start=1072
  _globals['_MSGSETORDERROUTERREVSHARERESPONSE']._serialized_end=1107
  _globals['_MSG']._serialized_start=1110
  _globals['_MSG']._serialized_end=1754
# @@protoc_insertion_point(module_scope)
