from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
EXPERT_CUSTOM_RENDERER_FIELD_NUMBER: _ClassVar[int]
expert_custom_renderer: _descriptor.FieldDescriptor
