# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/stats/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/stats/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.stats import params_pb2 as dydxprotocol_dot_stats_dot_params__pb2
from v4_proto.dydxprotocol.stats import stats_pb2 as dydxprotocol_dot_stats_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/stats/query.proto\x12\x12\x64ydxprotocol.stats\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1f\x64ydxprotocol/stats/params.proto\x1a\x1e\x64ydxprotocol/stats/stats.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.stats.ParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryStatsMetadataRequest\"Q\n\x1aQueryStatsMetadataResponse\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32!.dydxprotocol.stats.StatsMetadata\"\x19\n\x17QueryGlobalStatsRequest\"J\n\x18QueryGlobalStatsResponse\x12.\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.dydxprotocol.stats.GlobalStats\"%\n\x15QueryUserStatsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"F\n\x16QueryUserStatsResponse\x12,\n\x05stats\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.stats.UserStats2\xd2\x04\n\x05Query\x12\x80\x01\n\x06Params\x12&.dydxprotocol.stats.QueryParamsRequest\x1a\'.dydxprotocol.stats.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/dydxprotocol/v4/stats/params\x12\x9d\x01\n\rStatsMetadata\x12-.dydxprotocol.stats.QueryStatsMetadataRequest\x1a..dydxprotocol.stats.QueryStatsMetadataResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/dydxprotocol/v4/stats/stats_metadata\x12\x95\x01\n\x0bGlobalStats\x12+.dydxprotocol.stats.QueryGlobalStatsRequest\x1a,.dydxprotocol.stats.QueryGlobalStatsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/dydxprotocol/v4/stats/global_stats\x12\x8d\x01\n\tUserStats\x12).dydxprotocol.stats.QueryUserStatsRequest\x1a*.dydxprotocol.stats.QueryUserStatsResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/v4/stats/user_statsB9Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.stats.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/dydxprotocol/v4/stats/params'
  _globals['_QUERY'].methods_by_name['StatsMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StatsMetadata']._serialized_options = b'\202\323\344\223\002\'\022%/dydxprotocol/v4/stats/stats_metadata'
  _globals['_QUERY'].methods_by_name['GlobalStats']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GlobalStats']._serialized_options = b'\202\323\344\223\002%\022#/dydxprotocol/v4/stats/global_stats'
  _globals['_QUERY'].methods_by_name['UserStats']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserStats']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/v4/stats/user_stats'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=171
  _globals['_QUERYPARAMSREQUEST']._serialized_end=191
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=193
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=264
  _globals['_QUERYSTATSMETADATAREQUEST']._serialized_start=266
  _globals['_QUERYSTATSMETADATAREQUEST']._serialized_end=293
  _globals['_QUERYSTATSMETADATARESPONSE']._serialized_start=295
  _globals['_QUERYSTATSMETADATARESPONSE']._serialized_end=376
  _globals['_QUERYGLOBALSTATSREQUEST']._serialized_start=378
  _globals['_QUERYGLOBALSTATSREQUEST']._serialized_end=403
  _globals['_QUERYGLOBALSTATSRESPONSE']._serialized_start=405
  _globals['_QUERYGLOBALSTATSRESPONSE']._serialized_end=479
  _globals['_QUERYUSERSTATSREQUEST']._serialized_start=481
  _globals['_QUERYUSERSTATSREQUEST']._serialized_end=518
  _globals['_QUERYUSERSTATSRESPONSE']._serialized_start=520
  _globals['_QUERYUSERSTATSRESPONSE']._serialized_end=590
  _globals['_QUERY']._serialized_start=593
  _globals['_QUERY']._serialized_end=1187
# @@protoc_insertion_point(module_scope)
