# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crisis/module/v1/module.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crisis/module/v1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/crisis/module/v1/module.proto\x12\x17\x63osmos.crisis.module.v1\x1a cosmos/app/v1alpha1/module.proto\"f\n\x06Module\x12\x1a\n\x12\x66\x65\x65_collector_name\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t:-\xba\xc0\x96\xda\x01\'\n%github.com/cosmos/cosmos-sdk/x/crisisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\'\n%github.com/cosmos/cosmos-sdk/x/crisis'
  _globals['_MODULE']._serialized_start=99
  _globals['_MODULE']._serialized_end=201
# @@protoc_insertion_point(module_scope)
