# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/delaymsg/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/delaymsg/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/delaymsg/tx.proto\x12\x15\x64ydxprotocol.delaymsg\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19google/protobuf/any.proto\"\x87\x01\n\x0fMsgDelayMessage\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12!\n\x03msg\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0c\x64\x65lay_blocks\x18\x03 \x01(\r:\x0e\x82\xe7\xb0*\tauthority\"%\n\x17MsgDelayMessageResponse\x12\n\n\x02id\x18\x01 \x01(\x04\x32m\n\x03Msg\x12\x66\n\x0c\x44\x65layMessage\x12&.dydxprotocol.delaymsg.MsgDelayMessage\x1a..dydxprotocol.delaymsg.MsgDelayMessageResponseB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_MSGDELAYMESSAGE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGDELAYMESSAGE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDELAYMESSAGE']._loaded_options = None
  _globals['_MSGDELAYMESSAGE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDELAYMESSAGE']._serialized_start=137
  _globals['_MSGDELAYMESSAGE']._serialized_end=272
  _globals['_MSGDELAYMESSAGERESPONSE']._serialized_start=274
  _globals['_MSGDELAYMESSAGERESPONSE']._serialized_end=311
  _globals['_MSG']._serialized_start=313
  _globals['_MSG']._serialized_end=422
# @@protoc_insertion_point(module_scope)
