# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/revshare.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/revshare.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/revshare/revshare.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"4\n\x1bMarketMapperRevShareDetails\x12\x15\n\rexpiration_ts\x18\x01 \x01(\x04\"\xaf\x01\n\x1bUnconditionalRevShareConfig\x12Y\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x42.dydxprotocol.revshare.UnconditionalRevShareConfig.RecipientConfigB\x04\xc8\xde\x1f\x00\x1a\x35\n\x0fRecipientConfig\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tshare_ppm\x18\x02 \x01(\r\"S\n\x13OrderRouterRevShare\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\tshare_ppm\x18\x02 \x01(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.revshare_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_UNCONDITIONALREVSHARECONFIG'].fields_by_name['configs']._loaded_options = None
  _globals['_UNCONDITIONALREVSHARECONFIG'].fields_by_name['configs']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERROUTERREVSHARE'].fields_by_name['address']._loaded_options = None
  _globals['_ORDERROUTERREVSHARE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MARKETMAPPERREVSHAREDETAILS']._serialized_start=112
  _globals['_MARKETMAPPERREVSHAREDETAILS']._serialized_end=164
  _globals['_UNCONDITIONALREVSHARECONFIG']._serialized_start=167
  _globals['_UNCONDITIONALREVSHARECONFIG']._serialized_end=342
  _globals['_UNCONDITIONALREVSHARECONFIG_RECIPIENTCONFIG']._serialized_start=289
  _globals['_UNCONDITIONALREVSHARECONFIG_RECIPIENTCONFIG']._serialized_end=342
  _globals['_ORDERROUTERREVSHARE']._serialized_start=344
  _globals['_ORDERROUTERREVSHARE']._serialized_end=427
# @@protoc_insertion_point(module_scope)
