# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64ydxprotocol/vault/tx.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\x1a\x14gogoproto/gogo.proto\"\xcc\x01\n\x15MsgDepositToMegavault\x12=\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"[\n\x1dMsgDepositToMegavaultResponse\x12:\n\rminted_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\x8e\x02\n\x18MsgWithdrawFromMegavault\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12\x64\n\x12min_quote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\x84\x01\n MsgWithdrawFromMegavaultResponse\x12`\n\x0equote_quantums\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xa5\x01\n\x1dMsgUpdateDefaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x02 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\'\n%MsgUpdateDefaultQuotingParamsResponse\"\xc2\x01\n\x11MsgSetVaultParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x03 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgSetVaultParamsResponse\"e\n\x0fMsgUnlockShares\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x15\n\rowner_address\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"W\n\x17MsgUnlockSharesResponse\x12<\n\x0funlocked_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\x90\x01\n\x17MsgUpdateOperatorParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"!\n\x1fMsgUpdateOperatorParamsResponse\"\xe8\x01\n\x12MsgAllocateToVault\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgAllocateToVaultResponse\"\xea\x01\n\x14MsgRetrieveFromVault\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgRetrieveFromVaultResponse\"\x82\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.dydxprotocol.vault.ParamsB\x04\xc8\xde\x1f\x00:\x10\x18\x01\x82\xe7\xb0*\tauthority\"\xcf\x01\n\x18MsgSetVaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12?\n\x0equoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x10\x18\x01\x82\xe7\xb0*\tauthority2\xa3\x07\n\x03Msg\x12r\n\x12\x44\x65positToMegavault\x12).dydxprotocol.vault.MsgDepositToMegavault\x1a\x31.dydxprotocol.vault.MsgDepositToMegavaultResponse\x12{\n\x15WithdrawFromMegavault\x12,.dydxprotocol.vault.MsgWithdrawFromMegavault\x1a\x34.dydxprotocol.vault.MsgWithdrawFromMegavaultResponse\x12\x8a\x01\n\x1aUpdateDefaultQuotingParams\x12\x31.dydxprotocol.vault.MsgUpdateDefaultQuotingParams\x1a\x39.dydxprotocol.vault.MsgUpdateDefaultQuotingParamsResponse\x12x\n\x14UpdateOperatorParams\x12+.dydxprotocol.vault.MsgUpdateOperatorParams\x1a\x33.dydxprotocol.vault.MsgUpdateOperatorParamsResponse\x12\x66\n\x0eSetVaultParams\x12%.dydxprotocol.vault.MsgSetVaultParams\x1a-.dydxprotocol.vault.MsgSetVaultParamsResponse\x12`\n\x0cUnlockShares\x12#.dydxprotocol.vault.MsgUnlockShares\x1a+.dydxprotocol.vault.MsgUnlockSharesResponse\x12i\n\x0f\x41llocateToVault\x12&.dydxprotocol.vault.MsgAllocateToVault\x1a..dydxprotocol.vault.MsgAllocateToVaultResponse\x12o\n\x11RetrieveFromVault\x12(.dydxprotocol.vault.MsgRetrieveFromVault\x1a\x30.dydxprotocol.vault.MsgRetrieveFromVaultResponseB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_MSGDEPOSITTOMEGAVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGDEPOSITTOMEGAVAULT']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE'].fields_by_name['minted_shares']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE'].fields_by_name['minted_shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['shares']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['min_quote_quantums']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['min_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_params']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUNLOCKSHARES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUNLOCKSHARES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNLOCKSHARES']._loaded_options = None
  _globals['_MSGUNLOCKSHARES']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUNLOCKSHARESRESPONSE'].fields_by_name['unlocked_shares']._loaded_options = None
  _globals['_MSGUNLOCKSHARESRESPONSE'].fields_by_name['unlocked_shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEOPERATORPARAMS']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGALLOCATETOVAULT']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGRETRIEVEFROMVAULT']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\030\001\202\347\260*\tauthority'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_options = b'\030\001\202\347\260*\tauthority'
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_start=266
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_end=470
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE']._serialized_start=472
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE']._serialized_end=563
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_start=566
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_end=836
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE']._serialized_start=839
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE']._serialized_end=971
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_start=974
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_end=1139
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_start=1141
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_end=1180
  _globals['_MSGSETVAULTPARAMS']._serialized_start=1183
  _globals['_MSGSETVAULTPARAMS']._serialized_end=1377
  _globals['_MSGSETVAULTPARAMSRESPONSE']._serialized_start=1379
  _globals['_MSGSETVAULTPARAMSRESPONSE']._serialized_end=1406
  _globals['_MSGUNLOCKSHARES']._serialized_start=1408
  _globals['_MSGUNLOCKSHARES']._serialized_end=1509
  _globals['_MSGUNLOCKSHARESRESPONSE']._serialized_start=1511
  _globals['_MSGUNLOCKSHARESRESPONSE']._serialized_end=1598
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_start=1601
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_end=1745
  _globals['_MSGUPDATEOPERATORPARAMSRESPONSE']._serialized_start=1747
  _globals['_MSGUPDATEOPERATORPARAMSRESPONSE']._serialized_end=1780
  _globals['_MSGALLOCATETOVAULT']._serialized_start=1783
  _globals['_MSGALLOCATETOVAULT']._serialized_end=2015
  _globals['_MSGALLOCATETOVAULTRESPONSE']._serialized_start=2017
  _globals['_MSGALLOCATETOVAULTRESPONSE']._serialized_end=2045
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_start=2048
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_end=2282
  _globals['_MSGRETRIEVEFROMVAULTRESPONSE']._serialized_start=2284
  _globals['_MSGRETRIEVEFROMVAULTRESPONSE']._serialized_end=2314
  _globals['_MSGUPDATEPARAMS']._serialized_start=2317
  _globals['_MSGUPDATEPARAMS']._serialized_end=2447
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_start=2450
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_end=2657
  _globals['_MSG']._serialized_start=2660
  _globals['_MSG']._serialized_end=3591
# @@protoc_insertion_point(module_scope)
