# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/genesis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as dydxprotocol_dot_accountplus_dot_accountplus__pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as dydxprotocol_dot_accountplus_dot_models__pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as dydxprotocol_dot_accountplus_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/accountplus/genesis.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\x1a*dydxprotocol/accountplus/accountplus.proto\x1a%dydxprotocol/accountplus/models.proto\x1a%dydxprotocol/accountplus/params.proto\"r\n\x11\x41uthenticatorData\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12L\n\x0e\x61uthenticators\x18\x02 \x03(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticatorB\x04\xc8\xde\x1f\x00\"\xf4\x01\n\x0cGenesisState\x12>\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32&.dydxprotocol.accountplus.AccountStateB\x04\xc8\xde\x1f\x00\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .dydxprotocol.accountplus.ParamsB\x04\xc8\xde\x1f\x00\x12\x1d\n\x15next_authenticator_id\x18\x03 \x01(\x04\x12M\n\x12\x61uthenticator_data\x18\x04 \x03(\x0b\x32+.dydxprotocol.accountplus.AuthenticatorDataB\x04\xc8\xde\x1f\x00\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_AUTHENTICATORDATA'].fields_by_name['authenticators']._loaded_options = None
  _globals['_AUTHENTICATORDATA'].fields_by_name['authenticators']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['accounts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['accounts']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['authenticator_data']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['authenticator_data']._serialized_options = b'\310\336\037\000'
  _globals['_AUTHENTICATORDATA']._serialized_start=212
  _globals['_AUTHENTICATORDATA']._serialized_end=326
  _globals['_GENESISSTATE']._serialized_start=329
  _globals['_GENESISSTATE']._serialized_end=573
# @@protoc_insertion_point(module_scope)
