# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/clob/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as dydxprotocol_dot_clob_dot_matches__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2
from v4_proto.dydxprotocol.clob import order_removals_pb2 as dydxprotocol_dot_clob_dot_order__removals__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64ydxprotocol/clob/tx.proto\x12\x11\x64ydxprotocol.clob\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a\x1f\x64ydxprotocol/clob/matches.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\x1a&dydxprotocol/clob/order_removals.proto\x1a+dydxprotocol/clob/liquidations_config.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"\x86\x01\n\x11MsgCreateClobPair\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\tclob_pair\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgCreateClobPairResponse\"X\n\x15MsgProposedOperations\x12?\n\x10operations_queue\x18\x01 \x03(\x0b\x32\x1f.dydxprotocol.clob.OperationRawB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dMsgProposedOperationsResponse\">\n\rMsgPlaceOrder\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\"\x17\n\x15MsgPlaceOrderResponse\"\x8f\x01\n\x0eMsgCancelOrder\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12\x18\n\x0egood_til_block\x18\x02 \x01(\rH\x00\x12\x1d\n\x13good_til_block_time\x18\x03 \x01(\x07H\x00\x42\x10\n\x0egood_til_oneof\"\x18\n\x16MsgCancelOrderResponse\"\xae\x01\n\x0eMsgBatchCancel\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12?\n\x12short_term_cancels\x18\x02 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatchB\x04\xc8\xde\x1f\x00\x12\x16\n\x0egood_til_block\x18\x03 \x01(\r\"6\n\nOrderBatch\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12\x12\n\nclient_ids\x18\x02 \x03(\r\"\x8f\x01\n\x16MsgBatchCancelResponse\x12;\n\x14short_term_succeeded\x18\x01 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatch\x12\x38\n\x11short_term_failed\x18\x02 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatch\"\x86\x01\n\x11MsgUpdateClobPair\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\tclob_pair\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgUpdateClobPairResponse\"\xaa\x01\n\x0cOperationRaw\x12-\n\x05match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatchH\x00\x12$\n\x1ashort_term_order_placement\x18\x02 \x01(\x0cH\x00\x12\x38\n\rorder_removal\x18\x03 \x01(\x0b\x32\x1f.dydxprotocol.clob.OrderRemovalH\x00\x42\x0b\n\toperation\"\xbd\x01\n%MsgUpdateEquityTierLimitConfiguration\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12W\n\x18\x65quity_tier_limit_config\x18\x02 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"/\n-MsgUpdateEquityTierLimitConfigurationResponse\"\xba\x01\n$MsgUpdateBlockRateLimitConfiguration\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12U\n\x17\x62lock_rate_limit_config\x18\x03 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\".\n,MsgUpdateBlockRateLimitConfigurationResponse\"\xa4\x01\n\x1bMsgUpdateLiquidationsConfig\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x13liquidations_config\x18\x02 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"%\n#MsgUpdateLiquidationsConfigResponse2\x9f\x08\n\x03Msg\x12p\n\x12ProposedOperations\x12(.dydxprotocol.clob.MsgProposedOperations\x1a\x30.dydxprotocol.clob.MsgProposedOperationsResponse\x12X\n\nPlaceOrder\x12 .dydxprotocol.clob.MsgPlaceOrder\x1a(.dydxprotocol.clob.MsgPlaceOrderResponse\x12[\n\x0b\x43\x61ncelOrder\x12!.dydxprotocol.clob.MsgCancelOrder\x1a).dydxprotocol.clob.MsgCancelOrderResponse\x12[\n\x0b\x42\x61tchCancel\x12!.dydxprotocol.clob.MsgBatchCancel\x1a).dydxprotocol.clob.MsgBatchCancelResponse\x12\x64\n\x0e\x43reateClobPair\x12$.dydxprotocol.clob.MsgCreateClobPair\x1a,.dydxprotocol.clob.MsgCreateClobPairResponse\x12\x64\n\x0eUpdateClobPair\x12$.dydxprotocol.clob.MsgUpdateClobPair\x1a,.dydxprotocol.clob.MsgUpdateClobPairResponse\x12\xa0\x01\n\"UpdateEquityTierLimitConfiguration\x12\x38.dydxprotocol.clob.MsgUpdateEquityTierLimitConfiguration\x1a@.dydxprotocol.clob.MsgUpdateEquityTierLimitConfigurationResponse\x12\x9d\x01\n!UpdateBlockRateLimitConfiguration\x12\x37.dydxprotocol.clob.MsgUpdateBlockRateLimitConfiguration\x1a?.dydxprotocol.clob.MsgUpdateBlockRateLimitConfigurationResponse\x12\x82\x01\n\x18UpdateLiquidationsConfig\x12..dydxprotocol.clob.MsgUpdateLiquidationsConfig\x1a\x36.dydxprotocol.clob.MsgUpdateLiquidationsConfigResponseB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATECLOBPAIR']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGPROPOSEDOPERATIONS'].fields_by_name['operations_queue']._loaded_options = None
  _globals['_MSGPROPOSEDOPERATIONS'].fields_by_name['operations_queue']._serialized_options = b'\310\336\037\000'
  _globals['_MSGPLACEORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGPLACEORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCANCELORDER'].fields_by_name['order_id']._loaded_options = None
  _globals['_MSGCANCELORDER'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCEL'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_MSGBATCHCANCEL'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCEL'].fields_by_name['short_term_cancels']._loaded_options = None
  _globals['_MSGBATCHCANCEL'].fields_by_name['short_term_cancels']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATECLOBPAIR']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATECLOBPAIR']._serialized_start=450
  _globals['_MSGCREATECLOBPAIR']._serialized_end=584
  _globals['_MSGCREATECLOBPAIRRESPONSE']._serialized_start=586
  _globals['_MSGCREATECLOBPAIRRESPONSE']._serialized_end=613
  _globals['_MSGPROPOSEDOPERATIONS']._serialized_start=615
  _globals['_MSGPROPOSEDOPERATIONS']._serialized_end=703
  _globals['_MSGPROPOSEDOPERATIONSRESPONSE']._serialized_start=705
  _globals['_MSGPROPOSEDOPERATIONSRESPONSE']._serialized_end=736
  _globals['_MSGPLACEORDER']._serialized_start=738
  _globals['_MSGPLACEORDER']._serialized_end=800
  _globals['_MSGPLACEORDERRESPONSE']._serialized_start=802
  _globals['_MSGPLACEORDERRESPONSE']._serialized_end=825
  _globals['_MSGCANCELORDER']._serialized_start=828
  _globals['_MSGCANCELORDER']._serialized_end=971
  _globals['_MSGCANCELORDERRESPONSE']._serialized_start=973
  _globals['_MSGCANCELORDERRESPONSE']._serialized_end=997
  _globals['_MSGBATCHCANCEL']._serialized_start=1000
  _globals['_MSGBATCHCANCEL']._serialized_end=1174
  _globals['_ORDERBATCH']._serialized_start=1176
  _globals['_ORDERBATCH']._serialized_end=1230
  _globals['_MSGBATCHCANCELRESPONSE']._serialized_start=1233
  _globals['_MSGBATCHCANCELRESPONSE']._serialized_end=1376
  _globals['_MSGUPDATECLOBPAIR']._serialized_start=1379
  _globals['_MSGUPDATECLOBPAIR']._serialized_end=1513
  _globals['_MSGUPDATECLOBPAIRRESPONSE']._serialized_start=1515
  _globals['_MSGUPDATECLOBPAIRRESPONSE']._serialized_end=1542
  _globals['_OPERATIONRAW']._serialized_start=1545
  _globals['_OPERATIONRAW']._serialized_end=1715
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_start=1718
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_end=1907
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_start=1909
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_end=1956
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_start=1959
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_end=2145
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_start=2147
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_end=2193
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_start=2196
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_end=2360
  _globals['_MSGUPDATELIQUIDATIONSCONFIGRESPONSE']._serialized_start=2362
  _globals['_MSGUPDATELIQUIDATIONSCONFIGRESPONSE']._serialized_end=2399
  _globals['_MSG']._serialized_start=2402
  _globals['_MSG']._serialized_end=3457
# @@protoc_insertion_point(module_scope)
