# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/sending/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/sending/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.sending import transfer_pb2 as dydxprotocol_dot_sending_dot_transfer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/sending/tx.proto\x12\x14\x64ydxprotocol.sending\x1a#dydxprotocol/sending/transfer.proto\"E\n\x11MsgCreateTransfer\x12\x30\n\x08transfer\x18\x01 \x01(\x0b\x32\x1e.dydxprotocol.sending.Transfer\"\x1b\n\x19MsgCreateTransferResponse\" \n\x1eMsgDepositToSubaccountResponse\"#\n!MsgWithdrawFromSubaccountResponse\"$\n\"MsgSendFromModuleToAccountResponse2\xf9\x03\n\x03Msg\x12j\n\x0e\x43reateTransfer\x12\'.dydxprotocol.sending.MsgCreateTransfer\x1a/.dydxprotocol.sending.MsgCreateTransferResponse\x12y\n\x13\x44\x65positToSubaccount\x12,.dydxprotocol.sending.MsgDepositToSubaccount\x1a\x34.dydxprotocol.sending.MsgDepositToSubaccountResponse\x12\x82\x01\n\x16WithdrawFromSubaccount\x12/.dydxprotocol.sending.MsgWithdrawFromSubaccount\x1a\x37.dydxprotocol.sending.MsgWithdrawFromSubaccountResponse\x12\x85\x01\n\x17SendFromModuleToAccount\x12\x30.dydxprotocol.sending.MsgSendFromModuleToAccount\x1a\x38.dydxprotocol.sending.MsgSendFromModuleToAccountResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.sending.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/types'
  _globals['_MSGCREATETRANSFER']._serialized_start=92
  _globals['_MSGCREATETRANSFER']._serialized_end=161
  _globals['_MSGCREATETRANSFERRESPONSE']._serialized_start=163
  _globals['_MSGCREATETRANSFERRESPONSE']._serialized_end=190
  _globals['_MSGDEPOSITTOSUBACCOUNTRESPONSE']._serialized_start=192
  _globals['_MSGDEPOSITTOSUBACCOUNTRESPONSE']._serialized_end=224
  _globals['_MSGWITHDRAWFROMSUBACCOUNTRESPONSE']._serialized_start=226
  _globals['_MSGWITHDRAWFROMSUBACCOUNTRESPONSE']._serialized_end=261
  _globals['_MSGSENDFROMMODULETOACCOUNTRESPONSE']._serialized_start=263
  _globals['_MSGSENDFROMMODULETOACCOUNTRESPONSE']._serialized_end=299
  _globals['_MSG']._serialized_start=302
  _globals['_MSG']._serialized_end=807
# @@protoc_insertion_point(module_scope)
