# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/share.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/share.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/share.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"i\n\tNumShares\x12\\\n\nnum_shares\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"j\n\nOwnerShare\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"h\n\x11OwnerShareUnlocks\x12\x15\n\rowner_address\x18\x01 \x01(\t\x12<\n\rshare_unlocks\x18\x02 \x03(\x0b\x32\x1f.dydxprotocol.vault.ShareUnlockB\x04\xc8\xde\x1f\x00\"_\n\x0bShareUnlock\x12\x33\n\x06shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13unlock_block_height\x18\x02 \x01(\rB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.share_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_NUMSHARES'].fields_by_name['num_shares']._loaded_options = None
  _globals['_NUMSHARES'].fields_by_name['num_shares']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_OWNERSHARE'].fields_by_name['owner']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_OWNERSHARE'].fields_by_name['shares']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_OWNERSHAREUNLOCKS'].fields_by_name['share_unlocks']._loaded_options = None
  _globals['_OWNERSHAREUNLOCKS'].fields_by_name['share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_SHAREUNLOCK'].fields_by_name['shares']._loaded_options = None
  _globals['_SHAREUNLOCK'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_NUMSHARES']._serialized_start=103
  _globals['_NUMSHARES']._serialized_end=208
  _globals['_OWNERSHARE']._serialized_start=210
  _globals['_OWNERSHARE']._serialized_end=316
  _globals['_OWNERSHAREUNLOCKS']._serialized_start=318
  _globals['_OWNERSHAREUNLOCKS']._serialized_end=422
  _globals['_SHAREUNLOCK']._serialized_start=424
  _globals['_SHAREUNLOCK']._serialized_end=519
# @@protoc_insertion_point(module_scope)
