# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/daemons/pricefeed/price_feed.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/daemons/pricefeed/price_feed.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/dydxprotocol/daemons/pricefeed/price_feed.proto\x12\x1e\x64ydxprotocol.daemons.pricefeed\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x19UpdateMarketPricesRequest\x12O\n\x14market_price_updates\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.daemons.pricefeed.MarketPriceUpdate\"\x1c\n\x1aUpdateMarketPricesResponse\"s\n\rExchangePrice\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x04\x12>\n\x10last_update_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x01\x90\xdf\x1f\x01\"n\n\x11MarketPriceUpdate\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12\x46\n\x0f\x65xchange_prices\x18\x02 \x03(\x0b\x32-.dydxprotocol.daemons.pricefeed.ExchangePrice2\xa2\x01\n\x10PriceFeedService\x12\x8d\x01\n\x12UpdateMarketPrices\x12\x39.dydxprotocol.daemons.pricefeed.UpdateMarketPricesRequest\x1a:.dydxprotocol.daemons.pricefeed.UpdateMarketPricesResponse\"\x00\x42\x41Z?github.com/dydxprotocol/v4-chain/protocol/daemons/pricefeed/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.pricefeed.price_feed_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dydxprotocol/v4-chain/protocol/daemons/pricefeed/api'
  _globals['_EXCHANGEPRICE'].fields_by_name['last_update_time']._loaded_options = None
  _globals['_EXCHANGEPRICE'].fields_by_name['last_update_time']._serialized_options = b'\310\336\037\001\220\337\037\001'
  _globals['_UPDATEMARKETPRICESREQUEST']._serialized_start=138
  _globals['_UPDATEMARKETPRICESREQUEST']._serialized_end=246
  _globals['_UPDATEMARKETPRICESRESPONSE']._serialized_start=248
  _globals['_UPDATEMARKETPRICESRESPONSE']._serialized_end=276
  _globals['_EXCHANGEPRICE']._serialized_start=278
  _globals['_EXCHANGEPRICE']._serialized_end=393
  _globals['_MARKETPRICEUPDATE']._serialized_start=395
  _globals['_MARKETPRICEUPDATE']._serialized_end=505
  _globals['_PRICEFEEDSERVICE']._serialized_start=508
  _globals['_PRICEFEEDSERVICE']._serialized_end=670
# @@protoc_insertion_point(module_scope)
