# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/accountplus/tx.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x8b\x01\n\x13MsgAddAuthenticator\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthenticator_type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c::\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**dydxprotocol/accountplus/add-authenticator\".\n\x1bMsgAddAuthenticatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"s\n\x16MsgRemoveAuthenticator\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:=\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*-dydxprotocol/accountplus/remove-authenticator\"1\n\x1eMsgRemoveAuthenticatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x8e\x01\n\x11MsgSetActiveState\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08:<\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*)dydxprotocol/accountplus/set-active-state\"\x1b\n\x19MsgSetActiveStateResponse\".\n\x0bTxExtension\x12\x1f\n\x17selected_authenticators\x18\x01 \x03(\x04\x32\xf7\x02\n\x03Msg\x12x\n\x10\x41\x64\x64\x41uthenticator\x12-.dydxprotocol.accountplus.MsgAddAuthenticator\x1a\x35.dydxprotocol.accountplus.MsgAddAuthenticatorResponse\x12\x81\x01\n\x13RemoveAuthenticator\x12\x30.dydxprotocol.accountplus.MsgRemoveAuthenticator\x1a\x38.dydxprotocol.accountplus.MsgRemoveAuthenticatorResponse\x12r\n\x0eSetActiveState\x12+.dydxprotocol.accountplus.MsgSetActiveState\x1a\x33.dydxprotocol.accountplus.MsgSetActiveStateResponseB?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_MSGADDAUTHENTICATOR']._loaded_options = None
  _globals['_MSGADDAUTHENTICATOR']._serialized_options = b'\202\347\260*\006sender\212\347\260**dydxprotocol/accountplus/add-authenticator'
  _globals['_MSGREMOVEAUTHENTICATOR']._loaded_options = None
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_options = b'\202\347\260*\006sender\212\347\260*-dydxprotocol/accountplus/remove-authenticator'
  _globals['_MSGSETACTIVESTATE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETACTIVESTATE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETACTIVESTATE']._loaded_options = None
  _globals['_MSGSETACTIVESTATE']._serialized_options = b'\202\347\260*\tauthority\212\347\260*)dydxprotocol/accountplus/set-active-state'
  _globals['_MSGADDAUTHENTICATOR']._serialized_start=135
  _globals['_MSGADDAUTHENTICATOR']._serialized_end=274
  _globals['_MSGADDAUTHENTICATORRESPONSE']._serialized_start=276
  _globals['_MSGADDAUTHENTICATORRESPONSE']._serialized_end=322
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_start=324
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_end=439
  _globals['_MSGREMOVEAUTHENTICATORRESPONSE']._serialized_start=441
  _globals['_MSGREMOVEAUTHENTICATORRESPONSE']._serialized_end=490
  _globals['_MSGSETACTIVESTATE']._serialized_start=493
  _globals['_MSGSETACTIVESTATE']._serialized_end=635
  _globals['_MSGSETACTIVESTATERESPONSE']._serialized_start=637
  _globals['_MSGSETACTIVESTATERESPONSE']._serialized_end=664
  _globals['_TXEXTENSION']._serialized_start=666
  _globals['_TXEXTENSION']._serialized_end=712
  _globals['_MSG']._serialized_start=715
  _globals['_MSG']._serialized_end=1090
# @@protoc_insertion_point(module_scope)
