# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/streaming.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/clob/streaming.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.subaccounts import streaming_pb2 as dydxprotocol_dot_subaccounts_dot_streaming__pb2
from v4_proto.dydxprotocol.prices import streaming_pb2 as dydxprotocol_dot_prices_dot_streaming__pb2
from v4_proto.dydxprotocol.clob import query_pb2 as dydxprotocol_dot_clob_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/clob/streaming.proto\x12\x11\x64ydxprotocol.clob\x1a(dydxprotocol/subaccounts/streaming.proto\x1a#dydxprotocol/prices/streaming.proto\x1a\x1d\x64ydxprotocol/clob/query.proto\"\xb6\x02\n\x18StagedFinalizeBlockEvent\x12<\n\norder_fill\x18\x01 \x01(\x0b\x32&.dydxprotocol.clob.StreamOrderbookFillH\x00\x12M\n\x11subaccount_update\x18\x02 \x01(\x0b\x32\x30.dydxprotocol.subaccounts.StreamSubaccountUpdateH\x00\x12\x44\n\x10orderbook_update\x18\x03 \x01(\x0b\x32(.dydxprotocol.clob.StreamOrderbookUpdateH\x00\x12>\n\x0cprice_update\x18\x04 \x01(\x0b\x32&.dydxprotocol.prices.StreamPriceUpdateH\x00\x42\x07\n\x05\x65ventB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.streaming_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_STAGEDFINALIZEBLOCKEVENT']._serialized_start=167
  _globals['_STAGEDFINALIZEBLOCKEVENT']._serialized_end=477
# @@protoc_insertion_point(module_scope)
