# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/listing/params.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/listing/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/listing/params.proto\x12\x14\x64ydxprotocol.listing\x1a\x14gogoproto/gogo.proto\"\x97\x02\n\x19ListingVaultDepositParams\x12j\n\x18new_vault_deposit_amount\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12k\n\x19main_vault_deposit_amount\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12!\n\x19num_blocks_to_lock_shares\x18\x03 \x01(\rB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['new_vault_deposit_amount']._loaded_options = None
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['new_vault_deposit_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['main_vault_deposit_amount']._loaded_options = None
  _globals['_LISTINGVAULTDEPOSITPARAMS'].fields_by_name['main_vault_deposit_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LISTINGVAULTDEPOSITPARAMS']._serialized_start=82
  _globals['_LISTINGVAULTDEPOSITPARAMS']._serialized_end=361
# @@protoc_insertion_point(module_scope)
