# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/revshare/query.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"%\n#QueryMarketMapperRevenueShareParams\"z\n+QueryMarketMapperRevenueShareParamsResponse\x12K\n\x06params\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00\"5\n QueryMarketMapperRevShareDetails\x12\x11\n\tmarket_id\x18\x01 \x01(\r\"u\n(QueryMarketMapperRevShareDetailsResponse\x12I\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00\"\"\n QueryUnconditionalRevShareConfig\"t\n(QueryUnconditionalRevShareConfigResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.UnconditionalRevShareConfigB\x04\xc8\xde\x1f\x00\"E\n\x18QueryOrderRouterRevShare\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"t\n QueryOrderRouterRevShareResponse\x12P\n\x16order_router_rev_share\x18\x01 \x01(\x0b\x32*.dydxprotocol.revshare.OrderRouterRevShareB\x04\xc8\xde\x1f\x00\x32\xe4\x06\n\x05Query\x12\xdf\x01\n\x1eMarketMapperRevenueShareParams\x12:.dydxprotocol.revshare.QueryMarketMapperRevenueShareParams\x1a\x42.dydxprotocol.revshare.QueryMarketMapperRevenueShareParamsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dydxprotocol/revshare/market_mapper_rev_share_params\x12\xe3\x01\n\x1bMarketMapperRevShareDetails\x12\x37.dydxprotocol.revshare.QueryMarketMapperRevShareDetails\x1a?.dydxprotocol.revshare.QueryMarketMapperRevShareDetailsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}\x12\xcf\x01\n\x1bUnconditionalRevShareConfig\x12\x37.dydxprotocol.revshare.QueryUnconditionalRevShareConfig\x1a?.dydxprotocol.revshare.QueryUnconditionalRevShareConfigResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dydxprotocol/revshare/unconditional_rev_share\x12\xc0\x01\n\x13OrderRouterRevShare\x12/.dydxprotocol.revshare.QueryOrderRouterRevShare\x1a\x37.dydxprotocol.revshare.QueryOrderRouterRevShareResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/dydxprotocol/revshare/order_router_rev_share/{address}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE'].fields_by_name['config']._loaded_options = None
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE'].fields_by_name['config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYORDERROUTERREVSHARE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYORDERROUTERREVSHARE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYORDERROUTERREVSHARERESPONSE'].fields_by_name['order_router_rev_share']._loaded_options = None
  _globals['_QUERYORDERROUTERREVSHARERESPONSE'].fields_by_name['order_router_rev_share']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._serialized_options = b'\202\323\344\223\0027\0225/dydxprotocol/revshare/market_mapper_rev_share_params'
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._serialized_options = b'\202\323\344\223\002D\022B/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}'
  _globals['_QUERY'].methods_by_name['UnconditionalRevShareConfig']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnconditionalRevShareConfig']._serialized_options = b'\202\323\344\223\0020\022./dydxprotocol/revshare/unconditional_rev_share'
  _globals['_QUERY'].methods_by_name['OrderRouterRevShare']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OrderRouterRevShare']._serialized_options = b'\202\323\344\223\0029\0227/dydxprotocol/revshare/order_router_rev_share/{address}'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_start=213
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_end=250
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_start=252
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_end=374
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_start=376
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_end=429
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_start=431
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_end=548
  _globals['_QUERYUNCONDITIONALREVSHARECONFIG']._serialized_start=550
  _globals['_QUERYUNCONDITIONALREVSHARECONFIG']._serialized_end=584
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_start=586
  _globals['_QUERYUNCONDITIONALREVSHARECONFIGRESPONSE']._serialized_end=702
  _globals['_QUERYORDERROUTERREVSHARE']._serialized_start=704
  _globals['_QUERYORDERROUTERREVSHARE']._serialized_end=773
  _globals['_QUERYORDERROUTERREVSHARERESPONSE']._serialized_start=775
  _globals['_QUERYORDERROUTERREVSHARERESPONSE']._serialized_end=891
  _globals['_QUERY']._serialized_start=894
  _globals['_QUERY']._serialized_end=1762
# @@protoc_insertion_point(module_scope)
