# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as dydxprotocol_dot_accountplus_dot_accountplus__pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as dydxprotocol_dot_accountplus_dot_models__pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as dydxprotocol_dot_accountplus_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/accountplus/query.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*dydxprotocol/accountplus/accountplus.proto\x1a%dydxprotocol/accountplus/models.proto\x1a%dydxprotocol/accountplus/params.proto\"&\n\x13\x41\x63\x63ountStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"U\n\x14\x41\x63\x63ountStateResponse\x12=\n\raccount_state\x18\x01 \x01(\x0b\x32&.dydxprotocol.accountplus.AccountState\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .dydxprotocol.accountplus.ParamsB\x04\xc8\xde\x1f\x00\"+\n\x18GetAuthenticatorsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"k\n\x19GetAuthenticatorsResponse\x12N\n\x16\x61\x63\x63ount_authenticators\x18\x01 \x03(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticator\"D\n\x17GetAuthenticatorRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x18\n\x10\x61uthenticator_id\x18\x02 \x01(\x04\"i\n\x18GetAuthenticatorResponse\x12M\n\x15\x61\x63\x63ount_authenticator\x18\x01 \x01(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticator2\xc9\x05\n\x05Query\x12\x8f\x01\n\x06Params\x12,.dydxprotocol.accountplus.QueryParamsRequest\x1a-.dydxprotocol.accountplus.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /dydxprotocol/accountplus/params\x12\xc7\x01\n\x10GetAuthenticator\x12\x31.dydxprotocol.accountplus.GetAuthenticatorRequest\x1a\x32.dydxprotocol.accountplus.GetAuthenticatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/dydxprotocol/accountplus/authenticator/{account}/{authenticator_id}\x12\xb8\x01\n\x11GetAuthenticators\x12\x32.dydxprotocol.accountplus.GetAuthenticatorsRequest\x1a\x33.dydxprotocol.accountplus.GetAuthenticatorsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/dydxprotocol/accountplus/authenticators/{account}\x12\xa8\x01\n\x0c\x41\x63\x63ountState\x12-.dydxprotocol.accountplus.AccountStateRequest\x1a..dydxprotocol.accountplus.AccountStateResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/dydxprotocol/accountplus/account_state/{address}B?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /dydxprotocol/accountplus/params'
  _globals['_QUERY'].methods_by_name['GetAuthenticator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAuthenticator']._serialized_options = b'\202\323\344\223\002F\022D/dydxprotocol/accountplus/authenticator/{account}/{authenticator_id}'
  _globals['_QUERY'].methods_by_name['GetAuthenticators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAuthenticators']._serialized_options = b'\202\323\344\223\0024\0222/dydxprotocol/accountplus/authenticators/{account}'
  _globals['_QUERY'].methods_by_name['AccountState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountState']._serialized_options = b'\202\323\344\223\0023\0221/dydxprotocol/accountplus/account_state/{address}'
  _globals['_ACCOUNTSTATEREQUEST']._serialized_start=240
  _globals['_ACCOUNTSTATEREQUEST']._serialized_end=278
  _globals['_ACCOUNTSTATERESPONSE']._serialized_start=280
  _globals['_ACCOUNTSTATERESPONSE']._serialized_end=365
  _globals['_QUERYPARAMSREQUEST']._serialized_start=367
  _globals['_QUERYPARAMSREQUEST']._serialized_end=387
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=389
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=466
  _globals['_GETAUTHENTICATORSREQUEST']._serialized_start=468
  _globals['_GETAUTHENTICATORSREQUEST']._serialized_end=511
  _globals['_GETAUTHENTICATORSRESPONSE']._serialized_start=513
  _globals['_GETAUTHENTICATORSRESPONSE']._serialized_end=620
  _globals['_GETAUTHENTICATORREQUEST']._serialized_start=622
  _globals['_GETAUTHENTICATORREQUEST']._serialized_end=690
  _globals['_GETAUTHENTICATORRESPONSE']._serialized_start=692
  _globals['_GETAUTHENTICATORRESPONSE']._serialized_end=797
  _globals['_QUERY']._serialized_start=800
  _globals['_QUERY']._serialized_end=1513
# @@protoc_insertion_point(module_scope)
