# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/bridge/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/bridge/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.bridge import bridge_event_info_pb2 as dydxprotocol_dot_bridge_dot_bridge__event__info__pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as dydxprotocol_dot_bridge_dot_params__pb2
from v4_proto.dydxprotocol.bridge import tx_pb2 as dydxprotocol_dot_bridge_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/bridge/query.proto\x12\x13\x64ydxprotocol.bridge\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a+dydxprotocol/bridge/bridge_event_info.proto\x1a dydxprotocol/bridge/params.proto\x1a\x1c\x64ydxprotocol/bridge/tx.proto\"\x19\n\x17QueryEventParamsRequest\"R\n\x18QueryEventParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .dydxprotocol.bridge.EventParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryProposeParamsRequest\"V\n\x1aQueryProposeParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".dydxprotocol.bridge.ProposeParamsB\x04\xc8\xde\x1f\x00\"\x1a\n\x18QuerySafetyParamsRequest\"T\n\x19QuerySafetyParamsResponse\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.dydxprotocol.bridge.SafetyParamsB\x04\xc8\xde\x1f\x00\"#\n!QueryAcknowledgedEventInfoRequest\"^\n\"QueryAcknowledgedEventInfoResponse\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32$.dydxprotocol.bridge.BridgeEventInfoB\x04\xc8\xde\x1f\x00\"!\n\x1fQueryRecognizedEventInfoRequest\"\\\n QueryRecognizedEventInfoResponse\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32$.dydxprotocol.bridge.BridgeEventInfoB\x04\xc8\xde\x1f\x00\"<\n)QueryDelayedCompleteBridgeMessagesRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"w\n*QueryDelayedCompleteBridgeMessagesResponse\x12I\n\x08messages\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.bridge.DelayedCompleteBridgeMessageB\x04\xc8\xde\x1f\x00\"s\n\x1c\x44\x65layedCompleteBridgeMessage\x12=\n\x07message\x18\x01 \x01(\x0b\x32&.dydxprotocol.bridge.MsgCompleteBridgeB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\r2\xc9\x08\n\x05Query\x12\x98\x01\n\x0b\x45ventParams\x12,.dydxprotocol.bridge.QueryEventParamsRequest\x1a-.dydxprotocol.bridge.QueryEventParamsResponse\",\x82\xd3\xe4\x93\x02&\x12$/dydxprotocol/v4/bridge/event_params\x12\xa0\x01\n\rProposeParams\x12..dydxprotocol.bridge.QueryProposeParamsRequest\x1a/.dydxprotocol.bridge.QueryProposeParamsResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/v4/bridge/propose_params\x12\x9c\x01\n\x0cSafetyParams\x12-.dydxprotocol.bridge.QuerySafetyParamsRequest\x1a..dydxprotocol.bridge.QuerySafetyParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/dydxprotocol/v4/bridge/safety_params\x12\xc1\x01\n\x15\x41\x63knowledgedEventInfo\x12\x36.dydxprotocol.bridge.QueryAcknowledgedEventInfoRequest\x1a\x37.dydxprotocol.bridge.QueryAcknowledgedEventInfoResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//dydxprotocol/v4/bridge/acknowledged_event_info\x12\xb9\x01\n\x13RecognizedEventInfo\x12\x34.dydxprotocol.bridge.QueryRecognizedEventInfoRequest\x1a\x35.dydxprotocol.bridge.QueryRecognizedEventInfoResponse\"5\x82\xd3\xe4\x93\x02/\x12-/dydxprotocol/v4/bridge/recognized_event_info\x12\xe2\x01\n\x1d\x44\x65layedCompleteBridgeMessages\x12>.dydxprotocol.bridge.QueryDelayedCompleteBridgeMessagesRequest\x1a?.dydxprotocol.bridge.QueryDelayedCompleteBridgeMessagesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/dydxprotocol/v4/bridge/delayed_complete_bridge_messagesB:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_QUERYEVENTPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYEVENTPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPROPOSEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPROPOSEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSAFETYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYSAFETYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE'].fields_by_name['messages']._loaded_options = None
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE'].fields_by_name['messages']._serialized_options = b'\310\336\037\000'
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE'].fields_by_name['message']._loaded_options = None
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE'].fields_by_name['message']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['EventParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EventParams']._serialized_options = b'\202\323\344\223\002&\022$/dydxprotocol/v4/bridge/event_params'
  _globals['_QUERY'].methods_by_name['ProposeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ProposeParams']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/v4/bridge/propose_params'
  _globals['_QUERY'].methods_by_name['SafetyParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SafetyParams']._serialized_options = b'\202\323\344\223\002\'\022%/dydxprotocol/v4/bridge/safety_params'
  _globals['_QUERY'].methods_by_name['AcknowledgedEventInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AcknowledgedEventInfo']._serialized_options = b'\202\323\344\223\0021\022//dydxprotocol/v4/bridge/acknowledged_event_info'
  _globals['_QUERY'].methods_by_name['RecognizedEventInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecognizedEventInfo']._serialized_options = b'\202\323\344\223\002/\022-/dydxprotocol/v4/bridge/recognized_event_info'
  _globals['_QUERY'].methods_by_name['DelayedCompleteBridgeMessages']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelayedCompleteBridgeMessages']._serialized_options = b'\202\323\344\223\002:\0228/dydxprotocol/v4/bridge/delayed_complete_bridge_messages'
  _globals['_QUERYEVENTPARAMSREQUEST']._serialized_start=217
  _globals['_QUERYEVENTPARAMSREQUEST']._serialized_end=242
  _globals['_QUERYEVENTPARAMSRESPONSE']._serialized_start=244
  _globals['_QUERYEVENTPARAMSRESPONSE']._serialized_end=326
  _globals['_QUERYPROPOSEPARAMSREQUEST']._serialized_start=328
  _globals['_QUERYPROPOSEPARAMSREQUEST']._serialized_end=355
  _globals['_QUERYPROPOSEPARAMSRESPONSE']._serialized_start=357
  _globals['_QUERYPROPOSEPARAMSRESPONSE']._serialized_end=443
  _globals['_QUERYSAFETYPARAMSREQUEST']._serialized_start=445
  _globals['_QUERYSAFETYPARAMSREQUEST']._serialized_end=471
  _globals['_QUERYSAFETYPARAMSRESPONSE']._serialized_start=473
  _globals['_QUERYSAFETYPARAMSRESPONSE']._serialized_end=557
  _globals['_QUERYACKNOWLEDGEDEVENTINFOREQUEST']._serialized_start=559
  _globals['_QUERYACKNOWLEDGEDEVENTINFOREQUEST']._serialized_end=594
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE']._serialized_start=596
  _globals['_QUERYACKNOWLEDGEDEVENTINFORESPONSE']._serialized_end=690
  _globals['_QUERYRECOGNIZEDEVENTINFOREQUEST']._serialized_start=692
  _globals['_QUERYRECOGNIZEDEVENTINFOREQUEST']._serialized_end=725
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE']._serialized_start=727
  _globals['_QUERYRECOGNIZEDEVENTINFORESPONSE']._serialized_end=819
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESREQUEST']._serialized_start=821
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESREQUEST']._serialized_end=881
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE']._serialized_start=883
  _globals['_QUERYDELAYEDCOMPLETEBRIDGEMESSAGESRESPONSE']._serialized_end=1002
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE']._serialized_start=1004
  _globals['_DELAYEDCOMPLETEBRIDGEMESSAGE']._serialized_end=1119
  _globals['_QUERY']._serialized_start=1122
  _globals['_QUERY']._serialized_end=2219
# @@protoc_insertion_point(module_scope)
